@@ -34,16 +34,18 @@ function BinaryClient(socket, options) {
   this._socket.binaryType = 'arraybuffer';
   
   this._socket.addEventListener('open', function(){
-    // if node
-    self._socket._sender._socket.on('drain', function(){
+    self.emit('open');
+  });
+  // if node
+  if(this._socket._sender) {
+    this._socket._sender._socket.on('drain', function(){
       var ids = Object.keys(self.streams);
       for (var i = 0, ii = ids.length; i < ii; i++) {
         self.streams[ids[i]]._onDrain();
       }
     });
-    // end node
-    self.emit('open');
-  });
+  }
+  // end node
   this._socket.addEventListener('error', function(error){
     var ids = Object.keys(self.streams);
     for (var i = 0, ii = ids.length; i < ii; i++) {
